/**
Marble Widget Test Program

This program demonstrates the use of MarbleWidget and MarbleControlBox classes
in a Qt only program.
*/

// Qt Stuff
#include <QApplication>
#include <QHBoxLayout>
#include <QSplitter>

// Marble Stuff
#include "MarbleWidget.h"
#include "MarbleControlBox.h"
#include "MarbleModel.h"
#include "ViewParams.h"
#include "ClipPainter.h"

int main(int argc, char** argv)
{
	QApplication a(argc, argv);


	QWidget* mainWindow = new QWidget(0);
	mainWindow->setWindowTitle("Marble Test");

	QHBoxLayout* mainWindowLayout = new QHBoxLayout(mainWindow);
	mainWindowLayout->setMargin(3);
	mainWindowLayout->setSpacing(3);

	QSplitter* splitter = new QSplitter(mainWindow);
	mainWindowLayout->addWidget(splitter);

	MarbleControlBox* marbleControlBox = new MarbleControlBox;
	splitter->addWidget(marbleControlBox);

	MarbleWidget* marbleWidget = new MarbleWidget;
	splitter->addWidget(marbleWidget);

	marbleControlBox->addMarbleWidget(marbleWidget);
	marbleControlBox->setLocations( marbleWidget->placeMarkModel() );

	QObject::connect(marbleControlBox, SIGNAL(goHome()), marbleWidget, SLOT(goHome()));
	QObject::connect(marbleControlBox, SIGNAL(zoomIn()), marbleWidget, SLOT(zoomIn()));
	QObject::connect(marbleControlBox, SIGNAL(zoomOut()), marbleWidget, SLOT(zoomOut()));
	QObject::connect(marbleControlBox, SIGNAL(zoomChanged(int)), marbleWidget, SLOT(zoomView(int)));
	QObject::connect(marbleControlBox, SIGNAL(moveUp()), marbleWidget, SLOT(moveUp()));
	QObject::connect(marbleControlBox, SIGNAL(moveDown()), marbleWidget, SLOT(moveDown()));
	QObject::connect(marbleControlBox, SIGNAL(moveLeft()), marbleWidget, SLOT(moveLeft()));
	QObject::connect(marbleControlBox, SIGNAL(moveRight()), marbleWidget, SLOT(moveRight()));
	QObject::connect(marbleControlBox, SIGNAL(centerOn(const QModelIndex&)), marbleWidget, SLOT(centerOn(const QModelIndex&)));
	QObject::connect(marbleControlBox, SIGNAL(gpsPositionChanged(double,double)), marbleWidget, SLOT(centerOn(double,double)));

	mainWindow->resize(800, 600);
	mainWindow->show();

	return a.exec();
}

